# Verhaltenskodex für Mitwirkende

## Unser Versprechen

Wir als Mitglieder, Mitwirkende und Führungskräfte verpflichten uns, die Teilnahme an unserer Gemeinschaft zu einer belästigungsfreien Erfahrung für alle zu machen, unabhängig von Alter, Körpergröße, sichtbarer oder unsichtbarer Behinderung, ethnischer Herkunft, Geschlechtsmerkmalen, Geschlechtsidentität und -ausdruck, Erfahrungsniveau, Bildung, sozioökonomischem Status, Nationalität, persönlichem Erscheinungsbild, Rasse, Religion oder sexueller Identität und Orientierung.

Wir verpflichten uns, auf eine Weise zu handeln und zu interagieren, die zu einer offenen, einladenden, vielfältigen, inklusiven und gesunden Gemeinschaft beiträgt.

## Unsere Standards

Beispiele für Verhaltensweisen, die zu einer positiven Umgebung für unsere Gemeinschaft beitragen, sind:

* Empathie und Freundlichkeit gegenüber anderen Menschen zeigen
* Respekt vor unterschiedlichen Meinungen, Ansichten und Erfahrungen haben
* Konstruktives Feedback geben und annehmen
* Verantwortung übernehmen und sich bei denjenigen entschuldigen, die von unseren Fehlern betroffen sind, und aus den Erfahrungen lernen

* Konzentration auf das, was nicht nur für uns als Einzelpersonen, sondern für die gesamte Gemeinschaft am besten ist

Beispiele für inakzeptables Verhalten sind:

* Die Verwendung sexualisierter Sprache oder Darstellungen sowie sexuelle Aufmerksamkeit oder Annäherungsversuche jeglicher Art

* Trollen, beleidigende oder abfällige Kommentare sowie persönliche oder politische Angriffe
* Öffentliche oder private Belästigung
* Veröffentlichung privater Informationen anderer, wie z. B. einer physischen oder E-Mail-Adresse, ohne deren ausdrückliche Erlaubnis

* Anderes Verhalten, das in einem professionellen Umfeld vernünftigerweise als unangemessen angesehen werden könnte

## Durchsetzungsverantwortlichkeiten

Die Gemeinschaftsleiter sind dafür verantwortlich, unsere Standards für akzeptables Verhalten zu klären und durchzusetzen. Sie werden angemessene und faire Korrekturmaßnahmen ergreifen, wenn sie Verhalten als unangemessen, bedrohlich, beleidigend oder schädlich einstufen.

Gemeinschaftsleiter haben das Recht und die Pflicht, Kommentare, Commits, Code, Wiki-Bearbeitungen, Issues und andere Beiträge zu entfernen, zu bearbeiten oder abzulehnen, die nicht mit diesem Verhaltenskodex übereinstimmen. Sie werden die Gründe für Moderationsentscheidungen gegebenenfalls kommunizieren.

## Anwendungsbereich

Dieser Verhaltenskodex gilt in allen Gemeinschaftsräumen und auch, wenn eine Person die Gemeinschaft offiziell in öffentlichen Räumen vertritt. Beispiele für die Vertretung unserer Gemeinschaft sind die Verwendung einer offiziellen E-Mail-Adresse, das Posten über ein offizielles Social-Media-Konto oder das Handeln als ernannter Vertreter bei einer Online- oder Offline-Veranstaltung.

## Durchsetzung

Fälle von missbräuchlichem, belästigendem oder anderweitig inakzeptablem Verhalten können den für die Durchsetzung verantwortlichen Gemeinschaftsleitern unter aw@funstory.ai gemeldet werden. Alle Beschwerden werden umgehend und fair überprüft und untersucht.

Alle Gemeinschaftsleiter sind verpflichtet, die Privatsphäre und Sicherheit des Meldenden eines Vorfalls zu respektieren.

## Durchsetzungsrichtlinien

Die Gemeinschaftsleiter werden sich bei der Entscheidung über die Konsequenzen für Handlungen, die sie als Verstoß gegen diesen Verhaltenskodex erachten, an diese Richtlinien zur Gemeinschaftsauswirkung halten:

### 1. Korrektur

**Auswirkungen auf die Gemeinschaft**: Verwendung unangemessener Sprache oder anderem Verhalten, das in der Gemeinschaft als unprofessionell oder unerwünscht angesehen wird.

**Konsequenz**: Eine private, schriftliche Verwarnung von den Gemeinschaftsleitern, die Klarheit über die Art des Verstoßes und eine Erklärung bietet, warum das Verhalten unangemessen war. Eine öffentliche Entschuldigung kann verlangt werden.

### 2. Warnung

**Auswirkungen auf die Gemeinschaft**: Eine Verletzung durch einen einzelnen Vorfall oder eine Reihe von Handlungen.

**Konsequenz**: Eine Warnung mit Konsequenzen für fortgesetztes Verhalten. Keine Interaktion mit den beteiligten Personen, einschließlich unerwünschter Interaktion mit denen, die den Verhaltenskodex durchsetzen, für einen bestimmten Zeitraum. Dies umfasst die Vermeidung von Interaktionen in Gemeinschaftsräumen sowie in externen Kanälen wie sozialen Medien. Die Verletzung dieser Bedingungen kann zu einer vorübergehenden oder dauerhaften Sperre führen.

### 3. Temporäres Verbot

**Auswirkungen auf die Gemeinschaft**: Eine schwerwiegende Verletzung der Gemeinschaftsstandards, einschließlich anhaltend unangemessenen Verhaltens.

**Konsequenz**: Ein vorübergehendes Verbot jeglicher Art von Interaktion oder öffentlicher Kommunikation mit der Gemeinschaft für einen bestimmten Zeitraum. Während dieses Zeitraums sind keine öffentlichen oder privaten Interaktionen mit den beteiligten Personen erlaubt, einschließlich unerwünschter Kontakte mit denen, die den Verhaltenskodex durchsetzen. Die Verletzung dieser Bedingungen kann zu einem dauerhaften Ausschluss führen.

### 4. Dauerhafte Sperre

**Auswirkungen auf die Gemeinschaft**: Zeigt ein Muster der Verletzung von Gemeinschaftsstandards, einschließlich anhaltend unangemessenen Verhaltens, Belästigung einer Einzelperson oder Aggression gegenüber oder Herabwürdigung von Gruppen von Personen.

**Konsequenz**: Ein dauerhaftes Verbot jeglicher Art von öffentlicher Interaktion innerhalb der Gemeinschaft.

## Zuschreibung

Dieser Verhaltenskodex ist angepasst vom [Contributor Covenant][homepage],  
Version 2.0, verfügbar unter  
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.  

Die Richtlinien zur Gemeinschaftsauswirkung wurden inspiriert von [Mozillas Leiter zur Durchsetzung des Verhaltenskodex](https://github.com/mozilla/diversity).  

[homepage]: https://www.contributor-covenant.org  

Für Antworten auf häufig gestellte Fragen zu diesem Verhaltenskodex siehe die [FAQ](#häufig-gestellte-fragen) unter  
https://www.contributor-covenant.org/faq. Übersetzungen sind verfügbar unter  
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Ein Teil des Inhalts dieser Seite wurde von GPT übersetzt und kann Fehler enthalten.</small></h6>